:orphan:

.. _ug-FolderImageLoader:

===============================
Folder Image Loader API
===============================

**The following API can be used to load a folder of images to create a representative dataset for PTQ calibration**

.. autoclass:: model_compression_toolkit.FolderImageLoader
    :members:


=================================
Default file types to scan
=================================

.. autodata:: model_compression_toolkit.common.data_loader.FILETYPES

